console.log("Is test.js being called?");

var CreateDialog = function() {
	console.log("(test.js) Direct injection of <iframe> for a dialog box.");
	var frame = document.createElement("iframe");
	frame.setAttribute("id", "some_frame");

	//All attributes must end in !important, because we don't want the retailer site's CSS styles to affect our popup.
	//CSS styles do not support hex values.
	frame.setAttribute("style",
		"position: fixed !important; " + //This fixes the position of the <iframe> to wherever we specify.
		"text-align: center !important; " +
		"vertical-align: middle !important; " +
		"margin: 0 auto !important; " + //This disables forcing margin spacing at the top, but allows the
		//	<iframe> to be positioned left or right.
		"overflow: auto !important; " + //Specifies whether to clip content or add scrollbars when an
		//	element's content is too big to fit in a specified area.
		"clip: auto !important; " + //This lets us specify a rectangle to clip an absolutely
		//	positioned element. We don't want to clip anything, so we
		//	set it to be "auto" by default.
		"top: auto !important; " + //Distances from top and from right are all set to a certain number,
		//	which sets the <iframe> to be how far in the top right corner.
		"right: auto !important; " +
		"left: auto !important; " + //Left and bottom should be auto by default.
		"bottom: auto !important; " +
		"border: 5px solid transparent !important; " + //Border helps to add spacings on the edges without affecting
		//	margins.
		"display: block !important; " + //Don't inline the contents, else the layouts will be erratic.
		"z-index: 2147483647 !important; " + //In 3D world space, the default user's view is orthographic.
		//	By making our popup be very close to the camera, we avoid
		//	getting blocked by any other objects on the screen.
		"border-style: none !important; " + //No insets. No gray-ish border on the outside.
		"opacity: 0.0; " + //We start out from 1.0f, or 100% opaque.
		"-webkit-transition-delay: 0s !important; " +
		"-moz-transition-delay: 0s !important; " +
		"-o-transition-delay: 0s !important; " +
		"transition-delay: 0s !important; " +
		"-webkit-transition-duration: 0.2s !important; " +
		"-moz-transition-duration: 0.2s !important; " +
		"-o-transition-duration: 0.2s !important; " +
		"transition-duration: 0.2s !important; " +
		"-webkit-transition-property: opacity !important; " +
		"-moz-transition-property: opacity !important; " +
		"-o-transition-property: opacity !important; " +
		"transition-property: opacity !important; " +
		"-webkit-transition-timing-function: ease !important; " +
		"-moz-transition-timing-function: ease !important; " +
		"-o-transition-timing-function: ease !important; " +
		"transition-timing-function: ease !important; " +
		"visibility: visible; " +
		//TODO(Thompson): Do we want left or right facing box shadows?
		"box-shadow: -3px 3px 5px #3e3e3e; " + //Adding some box shadows to make the <iframe> stand out more.
		"width: 300px; " +
		"height: auto; " +
		"background-color: transparent; "); //Avoid adding unwanted artifacts to the actual popup.
	frame.setAttribute("src", chrome.runtime.getURL("dialog.html"));
	frame.setAttribute("sandbox", "allow-scripts");

	document.body.insertBefore(frame, document.body.firstChild);

	//Workaround for CSS transition property not firing when the page has finished loading. (Animation)
	//Manually sets the opacity from 0.0 to 1.0, in order to show the popup, after 1 elapsed second.
	setTimeout(function() {
		let v = frame.attributes["style"].value;
		v = v.replace("opacity: 0.0", "opacity: 1.0");
		frame.attributes["style"].value = v;
		console.log("(test.js) SUCCESS.");
	}, 500);

	try {
		var innerDocument = frame.contentDocument;
		console.log("(test.js) frame", frame);
		console.log("(test.js) Inner document", innerDocument);
		if (innerDocument) {
			let output = innerDocument.getElementById("output");
			console.log("(test.js) Output:", output);
		}

		console.log("(test.js) Direct injection of <iframe> of the dialog is complete.");
	}
	catch (e) {

	}
};

/**
 * Adds a timeout of 1 second while the webpage is loading. This helps to reduce the number of times messages are not being listened
 * at the right times.
 *
 * Sends a message to the background scripts saying it is ready to receive data for processing and UI utilizations.
 * @return {void}
 */
console.log("(test.js) Adding the contentscript.js listener.");
chrome.runtime.onConnect.addListener(function(port) {

	//NOTE(Thompson): Port handling is sometimes confusing. The best known way thus far is to filter the port messages by checking their names, then handling them
	//on a case-by-case basis.
	switch (port.name) {
		case "testPort":
			//NOTE(Thompson): Handles hiding/closing the iframe dialog.
			port.onMessage.addListener(function(message) {
				switch (message.action) {
					case "closeFrame":
						console.log("(test.js) Handling the injected dialog");
						let frames = document.getElementById("some_frame");
						console.log(frames);
						if (frames) {
							//Completely remove frames from the document's body after receiving the message to close frame.
							console.log("(test.js) Removing the injected dialog.");
							document.body.removeChild(frames);
						}
						break;
					case "showDialog":
						CreateDialog();
						break;
					default:
						break;
				}
				return;
			});
			break;
		default:
			break;
	}
});

console.log("Initializing?");

window.addEventListener("load", function(){
    console.log("Loading something.");
    if (window.openDatabase){
        chrome.tabs.create({
            url: chrome.extension.getURL() + "/pageToShowFrame.html"
        }, function(tab){
            console.log("Doing something", tab);
        });
    }
    else {
        var creating = browser.tabs.update({
            url: chrome.runtime.getURL("pageToShowFrame.html")
        });
        creating.onsuccess = function(event){
            console.log(event);
        };
        creating.onerror = function(event){
            console.log(event);
        };
    }
});
